@@ -32,10 +32,15 @@ struct _DjvuDocument {
 	ddjvu_context_t  *d_context;
 	ddjvu_document_t *d_document;
 	ddjvu_format_t   *d_format;
+	ddjvu_format_t   *thumbs_format;
 
 	gchar            *uri;
 
 	DjvuText         *search;
+        
+        /* PS exporter */
+        gchar		 *ps_filename;
+        GString 	 *opts;
 };
 
 int  djvu_document_get_n_pages (EvDocument   *document);
