@@ -126,26 +126,26 @@ static void        pdf_print_context_free   (PdfPrintContext   *ctx);
 
 EV_BACKEND_REGISTER_WITH_CODE (PdfDocument, pdf_document,
 			 {
-				 G_IMPLEMENT_INTERFACE (EV_TYPE_DOCUMENT_SECURITY,
-							pdf_document_security_iface_init);
-				 G_IMPLEMENT_INTERFACE (EV_TYPE_DOCUMENT_THUMBNAILS,
-							pdf_document_document_thumbnails_iface_init);
-				 G_IMPLEMENT_INTERFACE (EV_TYPE_DOCUMENT_LINKS,
-							pdf_document_document_links_iface_init);
-				 G_IMPLEMENT_INTERFACE (EV_TYPE_DOCUMENT_IMAGES,
-							pdf_document_document_images_iface_init);
-				 G_IMPLEMENT_INTERFACE (EV_TYPE_DOCUMENT_FORMS,
-							pdf_document_document_forms_iface_init);
-				 G_IMPLEMENT_INTERFACE (EV_TYPE_DOCUMENT_FONTS,
-							pdf_document_document_fonts_iface_init);
-				 G_IMPLEMENT_INTERFACE (EV_TYPE_DOCUMENT_FIND,
-							pdf_document_find_iface_init);
-				 G_IMPLEMENT_INTERFACE (EV_TYPE_FILE_EXPORTER,
-							pdf_document_file_exporter_iface_init);
-				 G_IMPLEMENT_INTERFACE (EV_TYPE_SELECTION,
-							pdf_selection_iface_init);
-				 G_IMPLEMENT_INTERFACE (EV_TYPE_DOCUMENT_TRANSITION,
-							pdf_document_page_transition_iface_init);
+				 EV_BACKEND_IMPLEMENT_INTERFACE (EV_TYPE_DOCUMENT_SECURITY,
+								 pdf_document_security_iface_init);
+				 EV_BACKEND_IMPLEMENT_INTERFACE (EV_TYPE_DOCUMENT_THUMBNAILS,
+								 pdf_document_document_thumbnails_iface_init);
+				 EV_BACKEND_IMPLEMENT_INTERFACE (EV_TYPE_DOCUMENT_LINKS,
+								 pdf_document_document_links_iface_init);
+				 EV_BACKEND_IMPLEMENT_INTERFACE (EV_TYPE_DOCUMENT_IMAGES,
+								 pdf_document_document_images_iface_init);
+				 EV_BACKEND_IMPLEMENT_INTERFACE (EV_TYPE_DOCUMENT_FORMS,
+								 pdf_document_document_forms_iface_init);
+				 EV_BACKEND_IMPLEMENT_INTERFACE (EV_TYPE_DOCUMENT_FONTS,
+								 pdf_document_document_fonts_iface_init);
+				 EV_BACKEND_IMPLEMENT_INTERFACE (EV_TYPE_DOCUMENT_FIND,
+								 pdf_document_find_iface_init);
+				 EV_BACKEND_IMPLEMENT_INTERFACE (EV_TYPE_FILE_EXPORTER,
+								 pdf_document_file_exporter_iface_init);
+				 EV_BACKEND_IMPLEMENT_INTERFACE (EV_TYPE_SELECTION,
+								 pdf_selection_iface_init);
+				 EV_BACKEND_IMPLEMENT_INTERFACE (EV_TYPE_DOCUMENT_TRANSITION,
+								 pdf_document_page_transition_iface_init);
 			 });
 
 static void
@@ -1192,7 +1192,7 @@ pdf_document_images_get_image_mapping (EvDocumentImages *document_images,
 	poppler_page_free_image_mapping (mapping_list);
 	g_object_unref (poppler_page);
 
-	return retval;
+	return g_list_reverse (retval);
 }
 
 GdkPixbuf *
